==> kb-standard-0.0.1.tar.gz: kb-standard-0.0.1/readme.md <==
# Standard #########################################################################################################################


## table of contents ###############################################################################################

1. [module description – what the module does and why it is useful](#module-description)
2. [setup – the basics of getting started with `standard`](#setup)
	* [what `standard` affects](#what-standard-affects)
	* [setup requirements](#setup-requirements)
	* [beginning with `standard`](#beginning-with-standard)
3. [limitations – OS compatibility, etc.](#limitations)
4. [development – guide for contributing to the module](#development)


## module description ##############################################################################################

* This module provides a _select_ collection of _standardized_ functions and data types within the Puppet ® ecosystem.
  If you are familiar with the referenced standards, e. g. POSIX™ or RFC number so-and-so, you _will know_ how something works.
  Minor extensions that amount to de-facto standards are provided, too, and there are some bonus templates.
* “You write code for humans.”
  Identifiers are kept human-readable:
  No abbreviations are used.
  Particularly in a large code base the function of objects should be apparent without consulting other sources.


## setup ###########################################################################################################

### what `standard` affects ########################################################################

The `standard` module affects nothing (except occupying the `standard` identifier/namespace, duh!).


### setup requirements #############################################################################

There are no setup requirements.


### beginning with `standard` ######################################################################

Simply put the module data at its right location and use the functions, data types or templates it provides.
There are no manifests. You cannot `include` this module.


## limitations #####################################################################################################

The `standard` module has a number of limitations:

* Implementation limitations are documented in the [`reference.md`](./reference).
* There is no `Standard::InternetProtocolVersion6address` data type. ☹
* Not everything that was desired/considered for inclusion is indeed _formally_ standardized.
* Standards that focus on one operating system are deliberately ignored (e. g. ISO/IEC 23360‑\* “Linux Standard Base”).


## development #####################################################################################################

* Make your case (how is something useful for a system managed by Puppet),
  reference specific sections of standards,
  if possible provide implementation and documentation,
  and do not forgot a copyright statement (public domain) in the commit message(s) of any commit(s) you may provide.
* Note, this module focuses on free open-source systems.
  Access to standards needs to be royalty-free
  (cmp. [ISO standards](https://standards.ISO.org/ittf/PubliclyAvailableStandards/)).


[//]: # ( vim: set filetype=markdown textwidth=132 tabstop=2 noexpandtab backspace=eol,start,indent: )

==> kb-standard-0.0.2.tar.gz: kb-standard-0.0.2/readme.md <==
# Standard #########################################################################################################################


## table of contents ###############################################################################################

1. [module description – what the module does and why it is useful](#module-description)
2. [setup – the basics of getting started with `standard`](#setup)
	* [what `standard` affects](#what-standard-affects)
	* [setup requirements](#setup-requirements)
	* [beginning with `standard`](#beginning-with-standard)
3. [limitations – OS compatibility, etc.](#limitations)
4. [development – guide for contributing to the module](#development)


## module description ##############################################################################################

* This module provides a _select_ collection of _standardized_ functions and data types within the Puppet ® ecosystem.
  If you are familiar with the referenced standards, e. g. POSIX™ or RFC number so‑and‑so, you _will know_ how something works.
  Minor extensions that amount to de‑facto standards are provided, too, and there are some bonus templates.
* “You write code for humans.”
  Identifiers are kept human‐readable:
  No abbreviations are used.
  Particularly in a large code base the function of objects should be apparent without consulting other sources.


## setup ###########################################################################################################

### what `standard` affects ########################################################################

The `standard` module affects nothing (except occupying the `standard` identifier/namespace, duh!).


### setup requirements #############################################################################

There are no setup requirements.


### beginning with `standard` ######################################################################

Simply put the module data at its right location and use the functions, data types or templates it provides.
There are no manifests. You cannot `include` this module.


## limitations #####################################################################################################

The `standard` module has a number of limitations:

* Implementation limitations are documented in the [`reference.md`](./reference).
* There is no `Standard::InternetProtocolVersion6address` data type. ☹
* Not everything that was desired/considered for inclusion is indeed _formally_ standardized.
* Standards that focus on one operating system are deliberately ignored (e. g. ISO/IEC 23360‑\* “Linux Standard Base”).


## development #####################################################################################################

* Make your case (how is something useful for a system managed by Puppet),
  reference specific sections of standards,
  if possible provide implementation and documentation,
  and do not forgot a copyright statement (public domain) in the commit message(s) of any commit(s) you may provide.
* Note, this module focuses on free open‐source systems.
  Access to standards needs to be royalty‐free
  (cmp. [ISO standards](https://standards.ISO.org/ittf/PubliclyAvailableStandards/)).


[//]: # ( vim: set filetype=markdown textwidth=132 tabstop=2 noexpandtab backspace=eol,start,indent: )
